prng/seed

Types

A seed is the value that is used by the random number generation algorithm to come up with new pseudo-random values.

pub type Seed

Values

pub fn new(int: Int) -> Seed

Deprecated: use the `random.new_seed` function instead

Creates a new seed from a given integer.

pub fn random() -> Seed

Deprecated: use the `random.new_seed` function with a fixed value instead

Creates a new random seed. You can use it when you don’t care about having reproducible results and just need to get some values out of a generator using the random.step function.

Search Document