prng/seed

Types

A seed is the value that is used by the random number generation algorithm to come up with new pseudo-random values.

pub type Seed

Functions

pub fn new(int: Int) -> Seed

Creates a new seed from a given integer.

Search Document